pub fn render_failure(envelope: &ErrorEnvelope<'_>, compact: bool) -> StringExpand description
Render a failure envelope: pretty or compact. The caller routes the result to stderr in both modes.
Panics
See render_success.
pub fn render_failure(envelope: &ErrorEnvelope<'_>, compact: bool) -> StringRender a failure envelope: pretty or compact. The caller routes the result to stderr in both modes.
See render_success.